@@ -8,7 +8,7 @@ from .redditor import Redditor
 from .subreddit import Subreddit
 
 if TYPE_CHECKING:  # pragma: no cover
-    from .... import praw
+    import praw
 
 
 class Message(InboxableMixin, ReplyableMixin, FullnameMixin, RedditBase):
