@@ -4,7 +4,7 @@ from typing import TYPE_CHECKING, Optional, Union
 from ....const import API_PATH
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ..... import praw
+    import praw
 
 
 class MessageableMixin:
